@@ -31,7 +31,7 @@ impl<'a> GetCommandPermissions<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<GuildCommandPermissions> {
-        let request = Request::from_route(Route::GetCommandPermissions {
+        let request = Request::from_route(&Route::GetCommandPermissions {
             application_id: self.application_id.0,
             command_id: self.command_id.0,
             guild_id: self.guild_id.0,
