@@ -33,7 +33,7 @@ impl<'a> GetGuildCommandPermissions<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ListBody<GuildCommandPermissions>> {
-        let request = Request::from_route(Route::GetGuildCommandPermissions {
+        let request = Request::from_route(&Route::GetGuildCommandPermissions {
             application_id: self.application_id.0,
             guild_id: self.guild_id.0,
         });
