@@ -91,8 +91,8 @@ impl<'a> SetCommandPermissions<'a> {
         })
     }
 
-    fn request(&self) -> Result<Request<'a>, Error> {
-        Request::builder(Route::SetCommandPermissions {
+    fn request(&self) -> Result<Request, Error> {
+        Request::builder(&Route::SetCommandPermissions {
             application_id: self.application_id.0,
             guild_id: self.guild_id.0,
         })
