@@ -324,8 +324,8 @@ impl<'a> UpdateFollowupMessage<'a> {
 
     // `self` needs to be consumed and the client returned due to parameters
     // being consumed in request construction.
-    fn request(&mut self) -> Result<Request<'a>, HttpError> {
-        let mut request = Request::builder(Route::UpdateWebhookMessage {
+    fn request(&mut self) -> Result<Request, HttpError> {
+        let mut request = Request::builder(&Route::UpdateWebhookMessage {
             message_id: self.message_id.0,
             token: self.token,
             webhook_id: self.application_id.0,
