@@ -21,7 +21,7 @@ impl<'a> CreateTypingTrigger<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<EmptyBody> {
-        let request = Request::from_route(Route::CreateTypingTrigger {
+        let request = Request::from_route(&Route::CreateTypingTrigger {
             channel_id: self.channel_id.0,
         });
 
