@@ -16,16 +16,16 @@ impl<'a> DeleteChannelPermission<'a> {
     }
 
     /// Delete an override for an member.
-    pub fn member(self, user_id: impl Into<UserId>) -> DeleteChannelPermissionConfigured<'a> {
-        self.configure(user_id.into().0)
+    pub const fn member(self, user_id: UserId) -> DeleteChannelPermissionConfigured<'a> {
+        self.configure(user_id.0)
     }
 
     /// Delete an override for an role.
-    pub fn role(self, role_id: impl Into<RoleId>) -> DeleteChannelPermissionConfigured<'a> {
-        self.configure(role_id.into().0)
+    pub const fn role(self, role_id: RoleId) -> DeleteChannelPermissionConfigured<'a> {
+        self.configure(role_id.0)
     }
 
-    fn configure(self, target_id: u64) -> DeleteChannelPermissionConfigured<'a> {
+    const fn configure(self, target_id: u64) -> DeleteChannelPermissionConfigured<'a> {
         DeleteChannelPermissionConfigured::new(self.http, self.channel_id, target_id)
     }
 }
