@@ -31,7 +31,7 @@ impl<'a> FollowNewsChannel<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<FollowedChannel> {
-        let mut request = Request::builder(Route::FollowNewsChannel {
+        let mut request = Request::builder(&Route::FollowNewsChannel {
             channel_id: self.channel_id.0,
         });
 
