@@ -21,7 +21,7 @@ impl<'a> GetPins<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ListBody<Message>> {
-        let request = Request::from_route(Route::GetPins {
+        let request = Request::from_route(&Route::GetPins {
             channel_id: self.channel_id.0,
         });
 
