@@ -27,7 +27,7 @@ impl<'a> GetChannelInvites<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ListBody<Invite>> {
-        let request = Request::from_route(Route::GetChannelInvites {
+        let request = Request::from_route(&Route::GetChannelInvites {
             channel_id: self.channel_id.0,
         });
 
