@@ -174,7 +174,7 @@ impl<'a> GetChannelMessages<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ListBody<Message>> {
-        let request = Request::from_route(Route::GetMessages {
+        let request = Request::from_route(&Route::GetMessages {
             after: None,
             around: None,
             before: None,
