@@ -128,7 +128,7 @@ impl<'a> GetChannelMessagesConfigured<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ListBody<Message>> {
-        let request = Request::from_route(Route::GetMessages {
+        let request = Request::from_route(&Route::GetMessages {
             after: self.after.map(|x| x.0),
             around: self.around.map(|x| x.0),
             before: self.before.map(|x| x.0),
