@@ -28,7 +28,7 @@ impl<'a> GetMessage<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<Message> {
-        let request = Request::from_route(Route::GetMessage {
+        let request = Request::from_route(&Route::GetMessage {
             channel_id: self.channel_id.0,
             message_id: self.message_id.0,
         });
