@@ -274,7 +274,7 @@ impl<'a> UpdateMessage<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<Message> {
-        let mut request = Request::builder(Route::UpdateMessage {
+        let mut request = Request::builder(&Route::UpdateMessage {
             channel_id: self.channel_id.0,
             message_id: self.message_id.0,
         });
