@@ -115,7 +115,7 @@ impl<'a> CreateStageInstance<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<EmptyBody> {
-        let mut request = Request::builder(Route::CreateStageInstance);
+        let mut request = Request::builder(&Route::CreateStageInstance);
 
         request = match request.json(&self.fields) {
             Ok(request) => request,
