@@ -119,7 +119,7 @@ impl<'a> UpdateStageInstance<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<EmptyBody> {
-        let mut request = Request::builder(Route::UpdateStageInstance {
+        let mut request = Request::builder(&Route::UpdateStageInstance {
             channel_id: self.channel_id.0,
         });
 
