@@ -26,7 +26,7 @@ impl<'a> GetBan<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<Ban> {
-        let request = Request::from_route(Route::GetBan {
+        let request = Request::from_route(&Route::GetBan {
             guild_id: self.guild_id.0,
             user_id: self.user_id.0,
         });
