@@ -66,7 +66,7 @@ impl<'a> CreateEmoji<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<Emoji> {
-        let mut request = Request::builder(Route::CreateEmoji {
+        let mut request = Request::builder(&Route::CreateEmoji {
             guild_id: self.guild_id.0,
         });
 
