@@ -21,7 +21,7 @@ impl<'a> GetGuildChannels<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ListBody<GuildChannel>> {
-        let request = Request::from_route(Route::GetChannels {
+        let request = Request::from_route(&Route::GetChannels {
             guild_id: self.guild_id.0,
         });
 
