@@ -18,7 +18,7 @@ impl<'a> GetGuildPreview<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<GuildPreview> {
-        let request = Request::from_route(Route::GetGuildPreview {
+        let request = Request::from_route(&Route::GetGuildPreview {
             guild_id: self.guild_id.0,
         });
 
