@@ -23,7 +23,7 @@ impl<'a> GetGuildVoiceRegions<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ListBody<VoiceRegion>> {
-        let request = Request::from_route(Route::GetGuildVoiceRegions {
+        let request = Request::from_route(&Route::GetGuildVoiceRegions {
             guild_id: self.guild_id.0,
         });
 
