@@ -21,7 +21,7 @@ impl<'a> GetGuildWebhooks<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ListBody<Webhook>> {
-        let request = Request::from_route(Route::GetGuildWebhooks {
+        let request = Request::from_route(&Route::GetGuildWebhooks {
             guild_id: self.guild_id.0,
         });
 
