@@ -16,7 +16,7 @@ impl<'a> GetGuildWelcomeScreen<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<WelcomeScreen> {
-        let request = Request::from_route(Route::GetGuildWelcomeScreen {
+        let request = Request::from_route(&Route::GetGuildWelcomeScreen {
             guild_id: self.guild_id.0,
         });
 
