@@ -26,7 +26,7 @@ impl<'a> GetMember<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<MemberBody> {
-        let request = Request::from_route(Route::GetMember {
+        let request = Request::from_route(&Route::GetMember {
             guild_id: self.guild_id.0,
             user_id: self.user_id.0,
         });
