@@ -28,7 +28,7 @@ impl<'a> RemoveMember<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<EmptyBody> {
-        let mut request = Request::builder(Route::RemoveMember {
+        let mut request = Request::builder(&Route::RemoveMember {
             guild_id: self.guild_id.0,
             user_id: self.user_id.0,
         });
