@@ -139,7 +139,7 @@ impl<'a> SearchGuildMembers<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<MemberListBody> {
-        let request = Request::from_route(Route::SearchGuildMembers {
+        let request = Request::from_route(&Route::SearchGuildMembers {
             guild_id: self.guild_id.0,
             limit: self.fields.limit,
             query: self.fields.query,
