@@ -21,7 +21,7 @@ impl<'a> GetGuildRoles<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ListBody<Role>> {
-        let request = Request::from_route(Route::GetGuildRoles {
+        let request = Request::from_route(&Route::GetGuildRoles {
             guild_id: self.guild_id.0,
         });
 
