@@ -32,7 +32,7 @@ impl<'a> UpdateCurrentUserNick<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<EmptyBody> {
-        let mut request = Request::builder(Route::UpdateNickname {
+        let mut request = Request::builder(&Route::UpdateNickname {
             guild_id: self.guild_id.0,
         });
 
