@@ -58,7 +58,7 @@ impl<'a> UpdateGuildChannelPositions<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<EmptyBody> {
-        let mut request = Request::builder(Route::UpdateGuildChannels {
+        let mut request = Request::builder(&Route::UpdateGuildChannels {
             guild_id: self.guild_id.0,
         });
 
