@@ -55,7 +55,7 @@ impl<'a> UpdateGuildWidget<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<GuildWidget> {
-        let mut request = Request::builder(Route::UpdateGuildWidget {
+        let mut request = Request::builder(&Route::UpdateGuildWidget {
             guild_id: self.guild_id.0,
         });
 
