@@ -62,7 +62,7 @@ impl<'a> UpdateUserVoiceState<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<EmptyBody> {
-        let mut request = Request::builder(Route::UpdateUserVoiceState {
+        let mut request = Request::builder(&Route::UpdateUserVoiceState {
             guild_id: self.guild_id.0,
             user_id: self.user_id.0,
         });
