@@ -135,7 +135,7 @@ impl<'a> CreateTemplate<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<Template> {
-        let mut request = Request::builder(Route::CreateTemplate {
+        let mut request = Request::builder(&Route::CreateTemplate {
             guild_id: self.guild_id.0,
         });
 
