@@ -21,7 +21,7 @@ impl<'a> GetTemplates<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ListBody<Template>> {
-        let request = Request::from_route(Route::GetTemplates {
+        let request = Request::from_route(&Route::GetTemplates {
             guild_id: self.guild_id.0,
         });
 
