@@ -1,10 +1,10 @@
 use super::{path::Path, route_display::RouteDisplay};
-use crate::request::Method;
-use std::borrow::Cow;
+use crate::request::{channel::reaction::RequestReactionType, Method};
+use twilight_model::id::RoleId;
 
 #[derive(Clone, Debug, Eq, Hash, PartialEq)]
 #[non_exhaustive]
-pub enum Route {
+pub enum Route<'a> {
     /// Route information to add a user to a guild.
     AddGuildMember { guild_id: u64, user_id: u64 },
     /// Route information to add a role to guild member.
@@ -24,7 +24,7 @@ pub enum Route {
         /// The ID of the guild.
         guild_id: u64,
         /// The reason for the ban.
-        reason: Option<String>,
+        reason: Option<&'a str>,
         /// The ID of the user.
         user_id: u64,
     },
@@ -55,7 +55,7 @@ pub enum Route {
     /// Route information to create a guild from a template.
     CreateGuildFromTemplate {
         /// Code of the template.
-        template_code: String,
+        template_code: &'a str,
     },
     /// Route information to create a guild's integration.
     CreateGuildIntegration {
@@ -75,7 +75,7 @@ pub enum Route {
         ///
         /// A user must have at least one of these roles to be able to be
         /// pruned.
-        include_roles: Vec<u64>,
+        include_roles: &'a [RoleId],
     },
     /// Route information to create an invite to a channel.
     CreateInvite {
@@ -94,7 +94,7 @@ pub enum Route {
         /// The ID of the channel.
         channel_id: u64,
         /// The URI encoded custom or unicode emoji.
-        emoji: String,
+        emoji: &'a RequestReactionType<'a>,
         /// The ID of the message.
         message_id: u64,
     },
@@ -177,14 +177,14 @@ pub enum Route {
     /// Route information to delete an invite.
     DeleteInvite {
         /// The unique invite code.
-        code: String,
+        code: &'a str,
     },
     /// Route information to delete the original interaction response.
     DeleteInteractionOriginal {
         /// The ID of the owner application
         application_id: u64,
         /// The token of the interaction.
-        interaction_token: String,
+        interaction_token: &'a str,
     },
     /// Route information to delete a channel's message.
     DeleteMessage {
@@ -211,7 +211,7 @@ pub enum Route {
         /// The ID of the channel.
         channel_id: u64,
         /// The URI encoded custom or unicode emoji.
-        emoji: String,
+        emoji: &'a RequestReactionType<'a>,
         /// The ID of the message.
         message_id: u64,
     },
@@ -223,16 +223,25 @@ pub enum Route {
         /// The ID of the target role or user.
         target_id: u64,
     },
+    /// Route information to delete the current user's reaction on a message.
+    DeleteReactionCurrentUser {
+        /// ID of the channel.
+        channel_id: u64,
+        /// URI encoded custom or unicode emoji.
+        emoji: &'a RequestReactionType<'a>,
+        /// ID of the message.
+        message_id: u64,
+    },
     /// Route information to delete a user's reaction on a message.
     DeleteReaction {
         /// The ID of the channel.
         channel_id: u64,
         /// The URI encoded custom or unicode emoji.
-        emoji: String,
+        emoji: &'a RequestReactionType<'a>,
         /// The ID of the message.
         message_id: u64,
-        /// The ID of the user. This can be `@me` to specify the current user.
-        user: String,
+        /// The ID of the user.
+        user_id: u64,
     },
     /// Route information to delete a guild's role.
     DeleteRole {
@@ -251,25 +260,25 @@ pub enum Route {
         /// The ID of the guild.
         guild_id: u64,
         /// The target template code.
-        template_code: String,
+        template_code: &'a str,
     },
     /// Route information to delete a message created by a webhook.
     DeleteWebhookMessage {
         message_id: u64,
-        token: String,
+        token: &'a str,
         webhook_id: u64,
     },
     /// Route information to delete a webhook.
     DeleteWebhook {
         /// The token of the webhook.
-        token: Option<String>,
+        token: Option<&'a str>,
         /// The ID of the webhook.
         webhook_id: u64,
     },
     /// Route information to execute a webhook by ID and token.
     ExecuteWebhook {
         /// The token of the webhook.
-        token: String,
+        token: &'a str,
         /// Whether to wait for a message response.
         wait: Option<bool>,
         /// The ID of the webhook.
@@ -336,6 +345,8 @@ pub enum Route {
     },
     /// Route information to get info about application the current bot user belongs to
     GetCurrentUserApplicationInfo,
+    /// Route information to get the current user.
+    GetCurrentUser,
     /// Route information to get an emoji by ID within a guild.
     GetEmoji {
         /// The ID of the emoji.
@@ -422,7 +433,7 @@ pub enum Route {
         ///
         /// A user must have at least one of these roles to be able to be
         /// pruned.
-        include_roles: Vec<u64>,
+        include_roles: &'a [RoleId],
     },
     /// Route information to get a guild's roles.
     GetGuildRoles {
@@ -463,19 +474,19 @@ pub enum Route {
         /// ID of the owner application.
         application_id: u64,
         /// Token of the interaction.
-        interaction_token: String,
+        interaction_token: &'a str,
     },
     /// Route information to get an invite.
     GetInvite {
         /// The unique invite code.
-        code: String,
+        code: &'a str,
         /// Whether to retrieve statistics about the invite.
         with_counts: bool,
     },
     /// Route information to get an invite with an expiration.
     GetInviteWithExpiration {
         /// The unique invite code.
-        code: String,
+        code: &'a str,
         /// Whether to retrieve statistics about the invite.
         with_counts: bool,
         /// Whether to retrieve the expiration date of the invite.
@@ -521,7 +532,7 @@ pub enum Route {
         /// The ID of the channel.
         channel_id: u64,
         /// The URI encoded custom or unicode emoji.
-        emoji: String,
+        emoji: &'a RequestReactionType<'a>,
         /// The maximum number of users to retrieve.
         limit: Option<u64>,
         /// The ID of the message.
@@ -535,18 +546,17 @@ pub enum Route {
     /// Route information to get a template.
     GetTemplate {
         /// The template code.
-        template_code: String,
+        template_code: &'a str,
     },
     /// Route information to get a list of templates from a guild.
     GetTemplates {
         /// The ID of the guild.
         guild_id: u64,
     },
-    /// Route information to get the current user.
+    /// Route information to get a user.
     GetUser {
-        /// The ID of the target user. This can be `@me` to specify the current
-        /// user.
-        target_user: String,
+        /// ID of the target user.
+        user_id: u64,
     },
     /// Route information to get the current user's connections.
     GetUserConnections,
@@ -558,7 +568,7 @@ pub enum Route {
     /// current user doesn't have access to it.
     GetWebhook {
         /// The token of the webhook.
-        token: Option<String>,
+        token: Option<&'a str>,
         /// The ID of the webhook.
         webhook_id: u64,
     },
@@ -567,7 +577,7 @@ pub enum Route {
         /// ID of the message.
         message_id: u64,
         /// Token of the webhook.
-        token: String,
+        token: &'a str,
         /// ID of the webhook.
         webhook_id: u64,
     },
@@ -576,7 +586,7 @@ pub enum Route {
         /// The ID of the interaction.
         interaction_id: u64,
         /// The token for the interaction.
-        interaction_token: String,
+        interaction_token: &'a str,
     },
     /// Route information to leave the guild.
     LeaveGuild {
@@ -613,7 +623,7 @@ pub enum Route {
         /// Upper limit of members to query for.
         limit: Option<u64>,
         /// Query to search by.
-        query: String,
+        query: &'a str,
     },
     /// Route information to set permissions of commands in a guild.
     SetCommandPermissions {
@@ -646,7 +656,7 @@ pub enum Route {
         /// The ID of the guild.
         guild_id: u64,
         /// The template code.
-        template_code: String,
+        template_code: &'a str,
     },
     /// Route information to unpin a message from a channel.
     UnpinMessage {
@@ -731,7 +741,7 @@ pub enum Route {
         /// The ID of the owner application.
         application_id: u64,
         /// The token for the interaction.
-        interaction_token: String,
+        interaction_token: &'a str,
     },
     /// Route information to update a member.
     UpdateMember {
@@ -782,7 +792,7 @@ pub enum Route {
         /// The ID of the guild.
         guild_id: u64,
         /// The template code.
-        template_code: String,
+        template_code: &'a str,
     },
     /// Route information to update a user's voice state.
     UpdateUserVoiceState {
@@ -794,37 +804,19 @@ pub enum Route {
     /// Route information to update a message created by a webhook.
     UpdateWebhookMessage {
         message_id: u64,
-        token: String,
+        token: &'a str,
         webhook_id: u64,
     },
     /// Route information to update a webhook.
     UpdateWebhook {
         /// The token of the webhook.
-        token: Option<String>,
+        token: Option<&'a str>,
         /// The ID of the webhook.
         webhook_id: u64,
     },
 }
 
-impl Route {
-    /// Separate a route into its parts: the HTTP method, the path enum to use
-    /// for ratelimit buckets, and the URI path.
-    ///
-    /// The method and URI path are useful for actually performing requests,
-    /// while the returned path enum is useful for ratelimiting.
-    #[allow(clippy::cognitive_complexity, clippy::too_many_lines)]
-    #[deprecated(
-        since = "0.5.1",
-        note = "use the individual `display`, `method`, and `path` methods"
-    )]
-    pub fn into_parts(self) -> (Method, Path, Cow<'static, str>) {
-        (
-            self.method(),
-            self.path(),
-            Cow::Owned(self.display().to_string()),
-        )
-    }
-
+impl<'a> Route<'a> {
     /// Display formatter of the route portion of a URL.
     ///
     /// # Examples
@@ -847,7 +839,7 @@ impl Route {
     /// use twilight_http::routing::Route;
     ///
     /// let route = Route::GetInvite {
-    ///     code: "twilight-rs".to_owned(),
+    ///     code: "twilight-rs",
     ///     with_counts: true,
     /// };
     ///
@@ -859,7 +851,7 @@ impl Route {
     ///
     /// [`GetInvite`]: Self::GetInvite
     /// [`GetPins`]: Self::GetPins
-    pub const fn display(&self) -> RouteDisplay<'_> {
+    pub const fn display(&'a self) -> RouteDisplay<'a> {
         RouteDisplay::new(self)
     }
 
@@ -897,6 +889,7 @@ impl Route {
             | Self::DeleteMessageSpecificReaction { .. }
             | Self::DeleteMessage { .. }
             | Self::DeletePermissionOverwrite { .. }
+            | Self::DeleteReactionCurrentUser { .. }
             | Self::DeleteReaction { .. }
             | Self::DeleteRole { .. }
             | Self::DeleteStageInstance { .. }
@@ -917,6 +910,7 @@ impl Route {
             | Self::GetChannels { .. }
             | Self::GetCommandPermissions { .. }
             | Self::GetCurrentUserApplicationInfo
+            | Self::GetCurrentUser
             | Self::GetEmoji { .. }
             | Self::GetEmojis { .. }
             | Self::GetGateway
@@ -1086,7 +1080,9 @@ impl Route {
                 Path::ChannelsIdMessages(*channel_id)
             }
             Self::CreatePrivateChannel | Self::GetUserPrivateChannels => Path::UsersIdChannels,
-            Self::CreateReaction { channel_id, .. } | Self::DeleteReaction { channel_id, .. } => {
+            Self::CreateReaction { channel_id, .. }
+            | Self::DeleteReactionCurrentUser { channel_id, .. }
+            | Self::DeleteReaction { channel_id, .. } => {
                 Path::ChannelsIdMessagesIdReactionsUserIdType(*channel_id)
             }
             Self::CreateRole { guild_id } | Self::GetGuildRoles { guild_id } => {
@@ -1169,7 +1165,7 @@ impl Route {
                 Path::ApplicationGuildCommandId(*application_id)
             }
             Self::GetCurrentUserApplicationInfo => Path::OauthApplicationsMe,
-            Self::GetUser { .. } | Self::UpdateCurrentUser => Path::UsersId,
+            Self::GetCurrentUser | Self::GetUser { .. } | Self::UpdateCurrentUser => Path::UsersId,
             Self::GetEmoji { guild_id, .. } | Self::UpdateEmoji { guild_id, .. } => {
                 Path::GuildsIdEmojisId(*guild_id)
             }
@@ -1228,14 +1224,14 @@ mod tests {
         assert_eq!(
             Method::Delete,
             Route::DeleteInvite {
-                code: "twilight-rs".to_owned(),
+                code: "twilight-rs",
             }
             .method()
         );
         assert_eq!(
             Method::Get,
             Route::GetInvite {
-                code: "twilight-rs".to_owned(),
+                code: "twilight-rs",
                 with_counts: false,
             }
             .method()
@@ -1253,7 +1249,7 @@ mod tests {
             Method::Put,
             Route::SyncTemplate {
                 guild_id: 123,
-                template_code: "abc".to_owned(),
+                template_code: "abc",
             }
             .method()
         );
